stream_feeds
library
Classes
AcceptFeedMemberInviteResponse
AcceptFollowRequest
AcceptFollowResponse
Action
ActionLogResponse
ActionSequence
ActivitiesFilterField
Represents a field that can be used in activities filtering.
ActivitiesQuery
A query for retrieving activities with filtering, sorting, and pagination.
ActivitiesSort
Represents a sorting operation for activities.
ActivitiesSortField
Defines the fields by which activities can be sorted.
Activity
Represents a single activity with its data and state.
A request for adding a comment to an activity.
ActivityAdded
An activity was added to a feed.
ActivityAddedEvent
Represents a list of activity comments with a query and state.
An observable state object that manages the current state of an activity comment list.
Manages the state of an activity comment list and handles state updates.
A query for retrieving comments for a specific activity.
ActivityData
An activity in the Stream Feeds system.
ActivityDeleted
An activity was deleted.
ActivityDeletedEvent
ActivityFeedbackEvent
ActivityFeedbackEventPayload
ActivityFeedbackRequest
ActivityFeedbackResponse
ActivityFilterConfig
ActivityHidden
An activity was hidden or unhidden by a user.
ActivityList
Represents a list of activities with a query and state.
ActivityListState
An observable state object that manages the current state of an activity list.
ActivityListStateNotifier
Manages the state of an activity list and handles state updates.
ActivityMarked
An activity was marked as read, seen, or watched.
ActivityMarkEvent
ActivityPinData
A pinned activity in the Stream Feeds system.
ActivityPinned
An activity was pinned to a feed.
ActivityPinnedEvent
ActivityPinResponse
ActivityProcessorConfig
ActivityReactionAddedEvent
ActivityReactionDeleted
A reaction was deleted from an activity.
ActivityReactionDeletedEvent
ActivityReactionList
Represents a list of activity reactions with a query and state.
ActivityReactionListState
An observable state object that manages the current state of an activity reaction list.
ActivityReactionListStateNotifier
Manages the state of an activity reaction list and handles state updates.
ActivityReactionsFilterField
Represents a field that can be used in activity reactions filtering.
ActivityReactionsQuery
A query for retrieving activity reactions with filtering, sorting, and pagination.
ActivityReactionsSort
Represents a sorting operation for activity reactions.
ActivityReactionsSortField
Defines the fields by which activity reactions can be sorted.
ActivityReactionUpdatedEvent
ActivityReactionUpserted
A reaction was added or updated on an activity.
ActivityRemovedFromFeed
An activity was removed from a specific feed.
ActivityRemovedFromFeedEvent
ActivityRequest
ActivityResponse
ActivityRestoredEvent
ActivitySelectorConfig
ActivityState
An observable state object that manages the current state of an activity.
ActivityStateNotifier
Manages the state of an activity and handles state updates.
ActivityUnpinned
An activity was unpinned from a feed.
ActivityUnpinnedEvent
A request for updating a comment to an activity.
ActivityUpdated
An activity was updated.
ActivityUpdatedEvent
AddActivityRequest
AddActivityResponse
AddBookmarkRequest
AddBookmarkResponse
AddFolderRequest
AddReactionRequest
AddReactionResponse
AddUserGroupMembersRequest
AddUserGroupMembersResponse
AggregatedActivityData
Aggregated activities in the Stream Feeds system.
AggregatedActivityResponse
AggregationConfig
AIAudioConfigRequest
AIAudioConfigResponse
AIImageConfig
AIImageLabelDefinition
AITextConfig
AIVideoConfigRequest
AIVideoConfigResponse
AndOperator <T extends Object >
Logical AND filter requiring all conditions to match.
AnySortComparator <T extends Object >
A type-erased wrapper for sort comparators that can work with any model type.
ApiErrorInterceptor
Interceptor that maps every failed request onto a StreamDioException
carrying the StreamException it represents.
ApiKeyInterceptor
AppData
Application configuration data.
AppealItemResponse
AppealRequest
AppealResponse
AppEventResponse
AppResponseFields
AppUpdatedEvent
Attachment
AttachmentFile
Cross-platform file wrapper for Stream attachments.
AttachmentUploadBatch
Several attachment uploads run as one operation.
AttachmentUploadState
The live state of one attachment upload.
AttachmentUploadTask
One attachment upload, as a handle on the operation itself.
Authenticating
The WebSocket connection is established and authentication is in progress.
AuthenticationFailed
A disconnection caused by the connection failing to authenticate.
AuthInterceptor
Interceptor that signs every request with the caller's token.
AutoCompleteOperator <T extends Object >
Word prefix matching filter for autocomplete.
AutomaticReconnectionPolicy
An interface that defines a policy for determining whether the WebSocket
should attempt an automatic reconnection based on specific conditions.
AutomodPlatformCircumventionConfig
AutomodRule
AutomodSemanticFiltersConfig
AutomodSemanticFiltersRule
AutomodToxicityConfig
AWSRekognitionRule
BackgroundStateReconnectionPolicy
A reconnection policy that checks the application's lifecycle state before
allowing reconnection. This prevents reconnection when the app is in the
background to save battery and resources.
BackgroundTransformer
The default Transformer for Dio .
BanActionRequestPayload
BanInfoResponse
BanOptions
BanRequest
BaseOptions
A set of base settings for each Dio().
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
BatchCancelling
The batch was cancelled and is waiting for its uploads to stop.
BatchFinished
Every upload in the batch has settled, and result holds one outcome per
requested attachment.
BatchFollowData
Represents the result of a batch follow operation.
BatchInProgress
The batch is working through its uploads.
BatchQueryActivityReactionsRequest
BatchQueryActivityReactionsResponse
BatchQueued
The batch has not started any of its uploads yet.
BatchStopping
An upload failed under a batch that gives up on the first failure, and the batch
is calling off the uploads that have not settled.
BatchUploadCancelled
The batch was called off through batch.cancel().
BatchUploadCompleted
Every attachment reached a terminal state on its own.
BatchUploadItemResult
One attachment's place in a BatchUploadResult .
BatchUploadProgress
How far a batch upload has got, both in attachments and in bytes.
BatchUploadResult
One outcome per requested attachment, and how the batch came to stop.
BatchUploadState
The live state of a batch upload.
BatchUploadStoppedOnError
An upload failed in a batch that gives up on the first failure, and the
rest were called off.
BlockActionRequestPayload
BlockedUserResponse
BlockListConfig
BlockListOptions
BlockListResponse
BlockListRule
BlockUsersRequest
BlockUsersResponse
BodyguardProfileSummary
BodyguardRule
BodyguardSeverityRule
BookmarkAdded
A bookmark was added.
BookmarkAddedEvent
BookmarkData
A bookmark in the Stream Feeds system.
BookmarkDeleted
A bookmark was deleted.
BookmarkDeletedEvent
BookmarkFolderData
A bookmark folder in the Stream Feeds system.
BookmarkFolderDeleted
A bookmark folder was deleted.
BookmarkFolderDeletedEvent
BookmarkFolderList
Represents a list of bookmark folders with a query and state.
BookmarkFolderListState
An observable state object that manages the current state of a bookmark folder list.
BookmarkFolderListStateNotifier
Manages the state of a bookmark folder list and handles state updates.
BookmarkFolderResponse
BookmarkFoldersFilterField
Represents a field that can be used in bookmark folders filtering.
BookmarkFoldersQuery
A query for retrieving bookmark folders with filtering, sorting, and pagination.
Represents a sorting operation for bookmark folders.
Defines the fields by which bookmark folders can be sorted.
BookmarkFolderUpdated
A bookmark folder was updated.
BookmarkFolderUpdatedEvent
BookmarkList
Represents a list of bookmarks with a query and state.
BookmarkListState
An observable state object that manages the current state of a bookmark list.
BookmarkListStateNotifier
Manages the state of a bookmark list and handles state updates.
BookmarkResponse
BookmarksFilterField
Represents a field that can be used in bookmarks filtering.
BookmarksQuery
A query for retrieving bookmarks with filtering, sorting, and pagination.
BookmarksSort
Represents a sorting operation for bookmarks.
BookmarksSortField
Defines the fields by which bookmarks can be sorted.
BookmarkUpdated
A bookmark was updated.
BookmarkUpdatedEvent
BoundingBox
A rectangular geographic region for area-based location filtering.
BulkActionAppealsRequest
BulkActionAppealsResponse
BulkAppealError
BulkAppealResult
BulkDeleteActionConfigRequest
BulkDeleteActionConfigResponse
BulkUpsertActionConfigRequest
BulkUpsertActionConfigResponse
BypassActionRequest
ByteBuffer
A sequence of bytes underlying a typed data object.
ByteData
A fixed-length, random-access sequence of bytes that also provides random
and unaligned access to the fixed-width integers and floating point
numbers represented by those bytes.
BytesBuilder
Builds a list of bytes, allowing bytes and lists of bytes to be added at the
end.
CallActionOptions
CallCustomPropertyParameters
CallRuleActionSequence
CallTypeRuleParameters
CallViolationCountParameters
CancelToken
Controls cancellation of Dio 's requests.
CastPollVoteRequest
CdnApi
CdnClient
Content Delivery Network (CDN) client for file operations.
ChangeFeedVisibilityRequest
ChangeFeedVisibilityResponse
ChannelConfigWithInfo
ChannelMemberPartialResponse
ChannelMemberResponse
ChannelMessageCountRuleParameters
ChannelMetadata
ChannelMute
ChannelPushPreferencesResponse
ChannelResponse
ChatDraftPayloadResponse
ChatDraftResponse
ChatMessageResponse
ChatModerationV2Response
ChatPreferences
ChatPreferencesInput
ChatPreferencesResponse
ChatReactionGroupResponse
ChatReactionGroupUserResponse
ChatReactionResponse
ChatReminderResponseData
ChatSharedLocationResponseData
CircularRegion
A circular geographic region for proximity-based location filtering.
ClosedCaptionRuleParameters
CollectionData
A collection in the Stream Feeds system.
CollectionRequest
CollectionResponse
Command
A comment was added to an activity.
A comment in the Stream Feeds system.
A comment was deleted.
A list of comments with a query and state.
An observable state object that manages the current state of a comment list.
Manages the state of a comment list and handles state updates.
A reaction was deleted from a comment.
Represents a list of comment reactions with a query and state.
An observable state object that manages the current state of a comment reaction list.
Manages the state of a comment reaction list and handles state updates.
Represents a field that can be used in comment reactions filtering.
A query for retrieving comment reactions with filtering, sorting, and pagination.
Represents a sorting operation for comment reactions.
Defines the fields by which comment reactions can be sorted.
A reaction was added or updated on a comment.
A query for retrieving replies to a specific comment.
Represents a list of comment replies with a query and state.
An observable state object that manages the current state of a comment reply list.
Manages the state of a comment reply list and handles state updates.
Represents a field that can be used in comments filtering.
A query for retrieving comments with filtering, sorting, and pagination.
Interface for comment data that can be sorted.
A comment was updated.
ComparableField <T extends Object >
A type-safe wrapper for ordering values.
ComparisonOperator <T extends Object >
Base class for comparison-based filter operations.
CompositeReconnectionPolicy
A composite reconnection policy that combines multiple policies using a
logical operator (AND/OR). This allows for complex reconnection
logic by combining multiple conditions.
ConfigResponse
Connected
The WebSocket is fully connected and authenticated.
Connecting
The WebSocket is attempting to establish a connection.
ConnectionIdInterceptor
Interceptor that injects the connection id into the request params.
ConnectionRecoveryHandler
A connection recovery handler with intelligent reconnection management.
ConnectTimeout
A disconnection caused by the connection not becoming usable in time.
ConnectUserDetailsRequest
ContainsOperator <T extends Object >
Containment filter for JSON and array subset matching.
ContentCountRuleParameters
ContentCustomPropertyCountParameters
ContentCustomPropertyParameters
CreateBlockListRequest
CreateBlockListResponse
CreateCollectionsRequest
CreateCollectionsResponse
CreateDeviceRequest
CreateFeedsBatchRequest
CreateFeedsBatchResponse
CreateGuestRequest
CreateGuestResponse
CreatePollOptionRequest
CreatePollRequest
CreateQueueRequest
CreateUserGroupRequest
CreateUserGroupResponse
CurrentPlatform
Platform detection utility for identifying the current runtime environment.
CustomActionRequestPayload
Data
DecayFunctionConfig
DefaultApi
DefaultRetryStrategy
Default implementation of RetryStrategy that uses exponential backoff
with jitter.
DeleteActionConfigResponse
DeleteActivitiesRequest
DeleteActivitiesResponse
DeleteActivityReactionResponse
DeleteActivityRequestPayload
DeleteActivityResponse
DeleteBookmarkFolderResponse
DeleteBookmarkResponse
DeleteCollectionsResponse
DeleteFeedResponse
DeleteMessageRequestPayload
DeleteModerationConfigResponse
DeleteReactionRequestPayload
DeleteUserMessagesRequestPayload
DeleteUserRequestPayload
DeliveryReceiptsResponse
DeviceResponse
Dio
Dio enables you to make HTTP requests easily.
DioMixin
Disconnected
The WebSocket connection is closed and not available for communication.
Disconnecting
The WebSocket connection is in the process of being closed.
DisconnectionSource
Represents the source or cause of a WebSocket disconnection.
Disposable
A convenience class to represent a disposable object.
DraftPayloadResponse
DraftResponse
DurationResponse
DynamicTokenProvider
A token provider that dynamically loads fresh JWT tokens using a custom function.
Endian
Endianness of number representation.
EnrichedActivity
EnrichedCollectionResponse
EnrichedReaction
EnrichmentOptions
EntityCreatorResponse
EqualOperator <T extends Object >
Equality filter using exact value matching.
ErrorInterceptorHandler
The handler for interceptors to handle error occurred during the request.
EscalatePayload
EscalationMetadata
EvaluationOperator <T extends Object >
Base class for text-based evaluation filters.
ExistsOperator <T extends Object >
Field existence/absence filter.
Failure
Represents failed result.
Feed
A feed represents a collection of activities and provides methods to interact with them.
FeedAddActivityRequest
A request for adding an activity to feeds.
FeedAdded
A feed was created.
FeedCreatedEvent
FeedData
A feed in the Stream Feeds system.
FeedDeleted
A feed was deleted.
FeedDeletedEvent
FeedGroup
FeedGroupChangedEvent
FeedGroupDeletedEvent
FeedGroupRestoredEvent
FeedId
A unique feed identifier.
FeedInput
FeedInputData
Input data for creating or updating a feed.
FeedList
Represents a list of feeds with a query and state.
FeedListState
An observable state object that manages the current state of a feed list.
FeedListStateNotifier
Manages the state of a feed list and handles state updates.
FeedMemberAdded
A member was added to a feed.
FeedMemberAddedEvent
FeedMemberBatchUpdate
Multiple feed members were updated in a batch.
FeedMemberData
A member of a feed.
FeedMemberRemoved
A member was removed from a feed.
FeedMemberRemovedEvent
FeedMemberRequest
FeedMemberRequestData
A member request for adding to a feed.
FeedMemberResponse
FeedMemberUpdated
A feed member was updated.
FeedMemberUpdatedEvent
FeedOwnData
FeedQuery
A query for retrieving and managing feed data from Stream Feeds.
FeedRequest
FeedResponse
FeedsActivityLocation
FeedsBookmarkResponse
FeedsCdnClient
FeedsConfig
Configuration settings for the Stream Feeds SDK.
FeedsEnrichedCollectionResponse
FeedsFeedResponse
FeedsFilterField
Represents a field that can be used in feeds filtering.
FeedsNotificationContext
FeedsNotificationParentActivity
FeedsNotificationTarget
FeedsNotificationTrigger
FeedsPreferences
FeedsPreferencesResponse
FeedsQuery
A query for retrieving feeds with filtering, sorting, and pagination.
FeedsReactionData
A reaction to an activity in the Stream Feeds system.
FeedsReactionGroupResponse
FeedsReactionResponse
FeedsShareResponse
FeedsSort
Represents a sorting operation for feeds.
FeedsSortField
Defines the fields by which feeds can be sorted.
FeedState
Represents the current state of a feed.
FeedStateNotifier
Manages the state of a feed and handles state updates.
FeedSuggestionData
A feed suggestion in the Stream Feeds system.
FeedSuggestionResponse
FeedsV3ActivityResponse
FeedUpdated
A feed was updated.
FeedUpdatedEvent
Field
FileUploadConfig
FileUploadConfigData
File upload configuration settings.
FileUploadRequest
FileUploadResponse
Filter <T extends Object >
Type-safe filter for querying data.
FilterConfigResponse
FilterField <T >
Type-safe field identifier for filtering and value extraction.
FlagCountRuleParameters
FlagItemResponse
FlagRequest
FlagUserOptions
Float32List
A fixed-length list of IEEE 754 single-precision binary floating-point
numbers that is viewable as a TypedData .
Float32x4
Four 32-bit floating point values.
Float32x4List
A fixed-length list of Float32x4 numbers that is viewable as a
TypedData .
Float64List
A fixed-length list of IEEE 754 double-precision binary floating-point
numbers that is viewable as a TypedData .
Float64x2
Float64x2 immutable value type and operations.
Float64x2List
A fixed-length list of Float64x2 numbers that is viewable as a
TypedData .
FloodConfig
FloodIdenticalConfig
FloodIdenticalRuleParameters
FloodSimilarConfig
FloodSimilarRuleParameters
FollowAdded
A follow relationship was created.
FollowBatchRequest
FollowBatchResponse
FollowBatchUpdate
Multiple follow relationships were updated in a batch.
FollowCreatedEvent
FollowData
A follow relationship between feeds.
FollowDeleted
A follow relationship was deleted.
FollowDeletedEvent
FollowList
Represents a list of follows with a query and state.
FollowListState
An observable state object that manages the current state of a follow list.
FollowListStateNotifier
Manages the state of a follow list and handles state updates.
FollowRequest
FollowResponse
FollowsFilterField
Represents a field that can be used in follows filtering.
FollowsQuery
A query for retrieving follow relationships with filtering, sorting, and pagination.
FollowsSort
Represents a sorting operation for follows.
FollowsSortField
Defines the fields by which follows can be sorted.
FollowUpdated
A follow relationship was updated.
FollowUpdatedEvent
FormData
A class to create readable "multipart/form-data" streams.
It can be used to submit forms and file uploads to http server.
FriendReactionsOptions
FullUserResponse
FusedTransformer
A Transformer that has a fast path for decoding UTF8-encoded JSON.
If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions , this transformer
is significantly faster than the default SyncTransformer and the BackgroundTransformer .
This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response,
which is faster than decoding the utf8-encoded JSON in two separate steps, since
Dart uses a special fast decoder for this case.
See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
GetActionConfigResponse
GetActivityResponse
GetAppealResponse
GetApplicationResponse
GetBlockedUsersResponse
GetConfigResponse
GetFeedCountsResponse
GetFollowSuggestionsResponse
GetOGResponse
GetOrCreateFeedRequest
GetOrCreateFeedResponse
GetOrCreateFollowResponse
GetOrCreateUnfollowRequest
GetOrCreateUnfollowResponse
GetUserGroupResponse
GetUserInterestsResponse
GoogleVisionConfig
GreaterOperator <T extends Object >
Greater-than comparison filter.
GreaterOrEqualOperator <T extends Object >
Greater-than-or-equal comparison filter.
HarmConfig
The headers class for requests and responses.
Interceptor that sets additional headers for all requests.
HealthCheckInfo
HealthCheckPingEvent
HttpClientAdapter
HttpAdapter is a bridge between Dio and HttpClient .
ImageContentParameters
ImageData
ImageRuleParameters
Images
ImageSize
ImageUploadRequest
ImageUploadResponse
ImportBlockListRequest
ImportBlockListResponse
InFlightCache <K , V >
Coalesces concurrent identical async calls by sharing a single in-flight
Future keyed by K.
Initialized
The initial state before any connection attempt has been made.
InOperator <T extends Object >
Membership test filter for list containment.
Int16List
A fixed-length list of 16-bit signed integers that is viewable as a
TypedData .
Int32List
A fixed-length list of 32-bit signed integers that is viewable as a
TypedData .
Int32x4
Int32x4 and operations.
Int32x4List
A fixed-length list of Int32x4 numbers that is viewable as a
TypedData .
Int64List
A fixed-length list of 64-bit signed integers that is viewable as a
TypedData .
Int8List
A fixed-length list of 8-bit signed integers.
Interceptor
Interceptor helps to deal with RequestOptions , Response ,
and DioException during the lifecycle of a request
before it reaches users.
Interceptors
A Queue-Model list for Interceptor s.
InterceptorsWrapper
A helper class to create interceptors in ease.
InterestTagResponse
InternetAvailabilityReconnectionPolicy
A reconnection policy that checks for internet connectivity before allowing
reconnection. This prevents unnecessary reconnection attempts when there's no
network available.
IPContentCountRuleParameters
IPFlagCountRuleParameters
KeyframeOCRRuleParameters
KeyframeRuleParameters
LabelThresholds
LessOperator <T extends Object >
Less-than comparison filter.
LessOrEqualOperator <T extends Object >
Less-than-or-equal comparison filter.
LifecycleStateProvider
A utility class for monitoring application lifecycle state changes.
ListBlockListResponse
ListDevicesResponse
ListOperator <T extends Object >
Base class for list-based filter operations.
ListParam <T >
Indicates a param being used as queries or form data,
and how does it gets formatted.
ListQueuesResponse
ListUserGroupsResponse
LLMConfig
LLMRule
Location
LocationCoordinate
A geographic coordinate with latitude and longitude.
LoggingInterceptor
An interceptor that reports each request and the response it gets.
LogicalOperator <T extends Object >
Base class for logical filter composition.
LogInterceptor
LogInterceptor is used to print logs during network requests.
It should be the last interceptor added,
otherwise modifications by following interceptors will not be logged.
This is because the execution of interceptors is in the order of addition.
MarkActivityRequest
MarkReviewedRequestPayload
MemberList
Represents a list of feed members with a query and state.
MemberListState
An observable state object that manages the current state of a member list.
MemberListStateNotifier
Manages the state of a member list and handles state updates.
MembersFilterField
Represents a field that can be used in feed members filtering.
MembershipLevelResponse
MembersQuery
A query for retrieving feed members with filtering, sorting, and pagination.
Represents a sorting operation for feed members.
Defines the fields by which feed members can be sorted.
MessageResponse
ModelUpdates <T >
Updates to a collection of items.
Moderation
Content moderation results from Stream's moderation system.
ModerationActionConfigResponse
ModerationBanResponse
ModerationCallResponse
ModerationClient
Controller exposing moderation functionalities.
ModerationConfigData
Configuration settings for Stream's moderation system.
ModerationConfigList
Represents a list of moderation configurations with a query and state.
ModerationConfigListState
An observable state object that manages the current state of a moderation config list.
ModerationConfigListStateNotifier
Manages the state of a moderation config list and handles state updates.
ModerationConfigsFilterField
Represents a field that can be used in moderation configs filtering.
ModerationConfigsQuery
A query for retrieving moderation configs with filtering, sorting, and pagination.
ModerationConfigsSort
Represents a sorting operation for moderation configs.
ModerationConfigsSortField
Defines the fields by which moderation configs can be sorted.
ModerationCustomActionEvent
ModerationFlaggedEvent
ModerationFlagResponse
ModerationMarkReviewedEvent
ModerationPayload
ModerationPayloadResponse
ModerationQueueResponse
ModerationV2Response
MultipartFile
An upload content that is a part of MultipartRequest.
This doesn't need to correspond to a physical file.
MutableEventEmitter <T extends StreamEvent >
A mutable event emitter with resolver support for event transformation.
MutableSharedEmitter <T >
A mutable emitter that broadcasts events to multiple listeners.
MutableStateEmitter <T >
A mutable emitter that maintains and broadcasts the current state.
MuteRequest
MuteResponse
NetworkStateProvider
A utility class for monitoring network connectivity changes.
NotificationConfig
NotificationContext
NotificationFeedUpdated
A notification feed was updated with new aggregated activities.
NotificationFeedUpdatedEvent
NotificationParentActivity
NotificationStatusResponse
NotificationTarget
NotificationTrigger
OCRContentParameters
OCRRule
OnlyUserID
Options
The configuration for a single request.
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
OrOperator <T extends Object >
Logical OR filter requiring any condition to match.
OwnBatchRequest
OwnBatchResponse
OwnUserResponse
Pagination information for a paginated response.
Data class representing a paginated result containing a list of items and pagination data.
PathExistsOperator <T extends Object >
Nested JSON path existence filter.
PinActivityRequest
PinActivityResponse
PollClosed
A poll was closed.
PollClosedFeedEvent
PollData
A poll in the Stream Feeds system.
PollDeleted
A poll was deleted.
PollDeletedFeedEvent
PollList
Represents a list of polls with a query and state.
PollListState
An observable state object that manages the current state of a poll list.
PollListStateNotifier
Manages the state of a poll list and handles state updates.
PollOptionData
A poll option in the Stream Feeds system.
PollOptionInput
PollOptionRequest
PollOptionResponse
PollOptionResponseData
PollResponse
PollResponseData
PollsFilterField
Represents a field that can be used in polls filtering.
PollsQuery
A query for retrieving polls with filtering, sorting, and pagination.
PollsSort
Represents a sorting operation for polls.
PollsSortField
Defines the fields by which polls can be sorted.
PollUpdated
A poll was updated or closed.
PollUpdatedFeedEvent
PollVoteCasted
A vote was cast on a poll.
PollVoteCastedFeedEvent
PollVoteChanged
A vote was changed on a poll.
PollVoteChangedFeedEvent
PollVoteData
A poll vote in the Stream Feeds system.
PollVoteList
Represents a list of poll votes with a query and state.
PollVoteListState
An observable state object that manages the current state of a poll vote list.
PollVoteListStateNotifier
Manages the state of a poll vote list and handles state updates.
PollVoteRemoved
A vote was removed from a poll.
PollVoteRemovedFeedEvent
PollVoteResponse
PollVoteResponseData
PollVotesFilterField
Represents a field that can be used in poll votes filtering.
PollVotesQuery
A query for retrieving poll votes with filtering, sorting, and pagination.
PollVotesResponse
PollVotesSort
Represents a sorting operation for poll votes.
PollVotesSortField
Defines the fields by which poll votes can be sorted.
PrivacySettingsResponse
PushNotificationConfig
PushNotificationsConfig
Push notification configuration settings.
PushPreferenceInput
PushPreferencesResponse
PushProviderInfo
Information about the push provider.
QueryActivitiesRequest
QueryActivitiesResponse
QueryActivityReactionsRequest
QueryActivityReactionsResponse
QueryActivitySharesResponse
QueryAppealsRequest
QueryAppealsResponse
QueryBookmarkFoldersRequest
QueryBookmarkFoldersResponse
QueryBookmarksRequest
QueryBookmarksResponse
QueryCollectionsRequest
QueryCollectionsResponse
QueryFeedMembersRequest
QueryFeedMembersResponse
QueryFeedsRequest
QueryFeedsResponse
QueryFollowsRequest
QueryFollowsResponse
QueryModerationConfigsRequest
QueryModerationConfigsResponse
QueryOperator <T extends Object >
Full-text search filter.
QueryPinnedActivitiesRequest
QueryPinnedActivitiesResponse
QueryPollsRequest
QueryPollsResponse
QueryPollVotesRequest
QueryReviewQueueRequest
QueryReviewQueueResponse
QueryUsersPayload
QueryUsersResponse
QueuedInterceptor
Interceptor in queue.
QueuedInterceptorsWrapper
A helper class to create QueuedInterceptor in ease.
QueueResponse
RankingConfig
Reaction
ReactionGroupData
A group of reactions of the same type.
ReactionGroupResponse
ReactionGroupUserResponse
ReactionResponse
ReadCollectionsResponse
ReadReceiptsResponse
RedirectRecord
A record that records the redirection happens during requests,
including status code, request method, and the location.
RejectAppealRequestPayload
RejectFeedMemberInviteResponse
RejectFollowRequest
RejectFollowResponse
ReminderResponseData
RemoveUserGroupMembersRequest
RemoveUserGroupMembersResponse
RepliesMeta
RequestInterceptorHandler
The handler for interceptors to handle before the request has been sent.
RequestOptions
The internal request option class that is the eventual result after
BaseOptions and Options are composed.
Response <T >
The Response class contains the payload (could be transformed)
that respond from the request, and other information of the response.
ResponseBody
The response wrapper class for adapters.
ResponseInterceptorHandler
The handler for interceptors to handle after respond.
RestoreActionRequestPayload
RestoreActivityResponse
Result <T >
A discriminated union that encapsulates a successful outcome with a value of type T
or a failure with an arbitrary Object error.
RetryStrategy
Interface that encapsulates the logic for computing delays for failed actions that need to be
retried.
ReviewQueueItemResponse
Role
RuleBuilderAction
RuleBuilderCondition
RuleBuilderConditionGroup
RuleBuilderConfig
RuleBuilderRule
SearchRolesResponse
SearchUserGroupsResponse
ServerInitiated
A disconnection that was initiated by the server.
ShadowBlockActionRequestPayload
ShareData
A share of an activity.
SharedEmitter <T >
A read-only emitter that broadcasts events to multiple listeners.
SharedLocationResponse
SharedLocationResponseData
SharedLocationsResponse
ShareResponse
SingleFollowResponse
Sort <T extends Object >
A sort specification that defines how to order a collection of objects.
SortComparator <T extends Object , V extends Object >
A comparator that can sort model instances by extracting comparable values.
SortField <T extends Object >
A sortable field definition that maps remote field names to local value extractors.
SortParam
SortParamRequest
StateEmitter <T >
A read-only emitter that maintains and broadcasts the current state.
StateUpdateEvent
Represents an event that may trigger a state update.
StaticTokenProvider
A token provider that uses a static token for a specific user.
StoriesConfig
StoriesFeedUpdated
A stories feed was updated with new activities.
StoriesFeedUpdatedEvent
StreamApiError
An API error response from the Stream API.
StreamAttachment
Represents a file attachment with type information.
StreamAttachmentUploader
An uploader of StreamAttachment s, sending their bytes through a
CdnClient .
StreamDateTimeConverter
A JsonConverter for the API's DateTime fields.
StreamEvent
Base interface for events that can be emitted through an EventEmitter .
StreamFeedsClient
Stream Feeds client for building scalable newsfeeds and activity streams.
StreamLogConfig
How much a Stream SDK reports, and where those records go.
StreamLogFilter
Decides which records are worth building, independently of where they end up.
StreamLogger
Writes log records under a tag.
StreamLogHandler
Where log records go.
StreamLogRecord
A single log record, as a handler receives it.
StreamWebSocketClient
A WebSocket client with connection management and event handling.
StreamWebSocketEngine <Inc , Out >
A WebSocket engine implementation that handles low-level WebSocket operations.
SubmitActionRequest
SubmitActionResponse
Success <T >
Represents successful result.
SyncTransformer
If you want to custom the transformation of request/response data,
you can provide a Transformer by your self, and replace
the transformer by setting the Dio.transformer .
SystemEnvironment
A class that represents the environment in which the Stream SDK is
running.
SystemEnvironmentManager
A manager class to handle the current SystemEnvironment .
SystemInitiated
A disconnection that was initiated by system-level conditions.
TextContentParameters
TextRuleParameters
Thresholds
TokenManager
Loads user authentication tokens from a TokenProvider , and caches the one in use.
TokenProvider
A provider for loading user authentication tokens.
TrackActivityMetricsEvent
TrackActivityMetricsEventResult
TrackActivityMetricsRequest
TrackActivityMetricsResponse
Transformer
Transformer allows changes to the request/response data before
it is sent/received to/from the server.
TranslateActivityRequest
TranslateActivityResponse
TypedData
A typed view of a sequence of bytes.
TypedDataList <E >
A TypedData fixed-length List -view on the bytes of buffer .
TypingIndicatorsResponse
Uint16List
A fixed-length list of 16-bit unsigned integers that is viewable as a
TypedData .
Uint32List
A fixed-length list of 32-bit unsigned integers that is viewable as a
TypedData .
Uint64List
A fixed-length list of 64-bit unsigned integers that is viewable as a
TypedData .
Uint8ClampedList
A fixed-length list of 8-bit unsigned integers.
Uint8List
A fixed-length list of 8-bit unsigned integers.
UnbanActionRequestPayload
UnbanResponse
UnblockActionRequestPayload
UnblockUsersRequest
UnblockUsersResponse
UnfollowBatchRequest
UnfollowBatchResponse
UnfollowPair
UnfollowResponse
UnHealthyConnection
A disconnection caused by failed connection health checks.
UnknownWSClientEvent
UnknownWSEvent
UnmuteRequest
UnmuteResponse
UnpinActivityResponse
UpdateActivityPartialRequest
UpdateActivityPartialResponse
UpdateActivityRequest
UpdateActivityResponse
UpdateBlockListRequest
UpdateBlockListResponse
UpdateBookmarkFolderRequest
UpdateBookmarkFolderResponse
UpdateBookmarkRequest
UpdateBookmarkResponse
UpdateCollectionRequest
UpdateCollectionsRequest
UpdateCollectionsResponse
UpdateFeedMembersRequest
UpdateFeedMembersResponse
UpdateFeedRequest
UpdateFeedResponse
UpdateFollowRequest
UpdateFollowResponse
UpdateLiveLocationRequest
UpdatePollOptionRequest
UpdatePollPartialRequest
UpdatePollRequest
UpdateQueueRequest
UpdateUserGroupRequest
UpdateUserGroupResponse
UpdateUserPartialRequest
UpdateUsersPartialRequest
UpdateUsersRequest
UpdateUsersResponse
UploadCancelled
The upload was called off.
UploadedAttachment
Represents a successfully uploaded attachment.
UploadedFile
Represents an uploaded file result from the CDN.
UploadFailed
The upload failed with error .
UploadInProgress
The upload is on its way, progress bytes of the file sent so far.
UploadPreparing
The upload is reading the file it is about to send.
UploadProgress
How far one upload has got, in bytes.
UploadQueued
The upload is waiting for a turn, and has not started sending.
UploadSuccess
The upload made it, attachment carrying its remote urls.
UpsertActionConfigItem
UpsertActionConfigRequest
UpsertActionConfigResponse
UpsertActivitiesRequest
UpsertActivitiesResponse
UpsertConfigRequest
UpsertConfigResponse
UpsertPushPreferencesRequest
UpsertPushPreferencesResponse
User
Model for the user's info.
UserBannedEvent
UserCreatedWithinParameters
UserCustomPropertyParameters
UserData
A user in the Stream Feeds system.
UserDeactivatedEvent
UserGroupMember
UserGroupResponse
UserIdenticalContentCountParameters
UserInitiated
A disconnection that was explicitly requested by the application.
UserList
Represents a list of users with a query and state.
UserListState
An observable state object that manages the current state of a user list.
UserListStateNotifier
Manages the state of a user list and handles state updates.
UserMuteResponse
UserReactivatedEvent
UserRequest
UserResponse
UserResponseCommonFields
UserResponsePrivacyFields
UserRoleParameters
UserRuleParameters
UsersFilterField
Represents a field that can be used in users filtering.
UsersQuery
A query for retrieving users with filtering, sorting, and pagination.
Represents a sorting operation for users.
Defines the fields by which users can be sorted.
UserToken
A user authentication token for Stream Core API access.
UserUnbannedEvent
UserUpdatedEvent
VelocityFilterConfig
VelocityFilterConfigRule
VideoCallRuleConfig
VideoContentParameters
VideoRuleParameters
VoteData
WebSocketAutomaticReconnectionPolicy
A reconnection policy that checks if automatic reconnection is enabled
based on the current state of the WebSocket connection.
WebSocketConnectionState
Represents the current state of a WebSocket connection.
WebSocketEngine <Outgoing >
Interface for WebSocket engine implementations.
WebSocketEngineListener <Incoming >
Interface for receiving WebSocket engine events.
WebSocketHealthListener
Interface for receiving WebSocket health monitoring events.
WebSocketHealthMonitor
A health monitor for WebSocket connections with ping/pong management.
WebSocketMessageCodec <Incoming , Outgoing >
Interface for WebSocket message encoding and decoding.
WebSocketOptions
Configuration options for establishing WebSocket connections.
WSAuthMessage
WsAuthMessageRequest
WSClientEvent <T extends WsEvent >
WSEvent <T extends WsEvent >
WsEvent
WsRequest
Enums
AuthType
Represents the types of authentication available for API access.
DioExceptionType
The exception enumeration indicates what type of exception
has happened during requests.
FileAccessMode
The file access mode when downloading a file, corresponds to a subset of
dart:io::FileMode .
InsertionAction
Defines how an item should be inserted into a list.
InterceptStep
The stage of a request a record came from.
LifecycleState
Enum representing the lifecycle state of the application.
ListFormat
Specifies the array format (a single parameter with multiple parameter
or multiple parameters with the same name).
and the separator for array items.
NetworkState
Enum representing the state of network connectivity.
NullOrdering
Defines how null values should be ordered in a sort operation.
Operator
Defines logical operators for combining multiple reconnection policies.
PlatformType
Enumeration of supported platform types.
PushNotificationsProvider
Supported push notification providers.
ResponseType
Indicates which transformation should be applied to the response data.
SortDirection
The direction of a sort operation.
StreamLogPriority
The severity of a log record.
UserType
The user authorization type.
Mixins
OptionsMixin
The mixin class for options that provides common attributes.
Typedefs
ActivitiesFilter
= Filter <ActivityData >
Represents a filtering operation for activities.
ActivityLocation
= Location
Use Location instead.
ActivityReactionsFilter
= Filter <FeedsReactionData >
Represents a filtering operation for activity reactions.
BanActionRequest
= BanActionRequestPayload
Use BanActionRequestPayload instead.
BanActionRequestDeleteMessages
= BanActionRequestPayloadDeleteMessages
Use BanActionRequestPayloadDeleteMessages instead.
BanResponse
= ModerationBanResponse
Use ModerationBanResponse instead.
BlockActionRequest
= BlockActionRequestPayload
Use BlockActionRequestPayload instead.
BookmarkFoldersFilter
= Filter <BookmarkFolderData >
Represents a filtering operation for bookmark folders.
BookmarksFilter
= Filter <BookmarkData >
Represents a filtering operation for bookmarks.
CallResponse
= ModerationCallResponse
Use ModerationCallResponse instead.
Represents a filtering operation for comment reactions.
Represents filtering options for comments queries.
ConnectionIdGetter
= String ? Function()
ConnectionStateEmitter
= StateEmitter <WebSocketConnectionState >
A state emitter for WebSocket connection state changes.
CustomActionRequest
= CustomActionRequestPayload
Use CustomActionRequestPayload instead.
DefaultTransformer
= SyncTransformer
DeleteActivityRequest
= DeleteActivityRequestPayload
Use DeleteActivityRequestPayload instead.
Use DeleteCommentRequestPayload instead.
DeleteMessageRequest
= DeleteMessageRequestPayload
Use DeleteMessageRequestPayload instead.
DeleteReactionRequest
= DeleteReactionRequestPayload
Use DeleteReactionRequestPayload instead.
DeleteUserRequest
= DeleteUserRequestPayload
Use DeleteUserRequestPayload instead.
DioError
= DioException
DioError describes the exception info when a request failed.
DioErrorType
= DioExceptionType
Deprecated in favor of DioExceptionType and will be removed in future major versions.
DioExceptionReadableStringBuilder
= String Function(DioException e )
The readable string builder's signature of
DioException.readableStringBuilder .
DioMediaType
= MediaType
The type (alias) for specifying the content-type of the MultipartFile.
EventEmitter <T extends StreamEvent >
= SharedEmitter <T >
A read-only event emitter constrained to StreamEvent subtypes.
EventResolver <T extends StreamEvent >
= T? Function(T event )
A function that inspects an event and optionally transforms it.
FeedsFilter
= Filter <FeedData >
Represents filtering options for feeds.
FilterFieldValueGetter <T , V >
= V? Function(T )
Function that extracts a field value from a model instance.
FlagResponse
= FlagItemResponse
Use FlagItemResponse instead.
FollowPair
= UnfollowPair
Use UnfollowPair instead.
FollowsFilter
= Filter <FollowData >
Represents a filtering operation for follows.
The signature that iterates header fields.
InterceptorErrorCallback
= void Function(DioException error , ErrorInterceptorHandler handler )
The signature of Interceptor.onError .
InterceptorSendCallback
= void Function(RequestOptions options , RequestInterceptorHandler handler )
The signature of Interceptor.onRequest .
InterceptorSuccessCallback
= void Function(Response response , ResponseInterceptorHandler handler )
The signature of Interceptor.onResponse .
JsonDecodeCallback
= FutureOr Function(String )
The callback definition for decoding a JSON string.
JsonEncodeCallback
= FutureOr <String > Function(Object )
The callback definition for encoding a JSON object.
LifecycleStateEmitter
= StateEmitter <LifecycleState >
A type alias for a state emitter that emits LifecycleState values.
LogPrint
= void Function(InterceptStep step , Object object )
Takes one line of the log, in place of the logger.
MarkReviewedRequest
= MarkReviewedRequestPayload
Use MarkReviewedRequestPayload instead.
MembersFilter
= Filter <FeedMemberData >
Represents a filtering operation for feed members.
ModerationConfigsFilter
= Filter <ModerationConfigData >
Represents filtering options for moderation configs.
MutableConnectionStateEmitter
= MutableStateEmitter <WebSocketConnectionState >
A mutable state emitter for WebSocket connection state changes.
NetworkStateEmitter
= StateEmitter <NetworkState >
A type alias for a state emitter that emits NetworkState values.
OnNewActivity
= InsertionAction Function(FeedQuery query , ActivityData activity , String currentUserId )
A callback function that determines how to handle a new activity.
OnTokenUpdated
= void Function(UserToken token )
A callback invoked whenever the manager caches a newly loaded token.
OwnUser
= OwnUserResponse
Use OwnUserResponse instead.
PingRequestBuilder
= WsRequest Function([HealthCheckInfo ? info ])
A function that builds ping requests for health checks.
Poll
= PollResponseData
Use PollResponseData instead.
PollOption
= PollOptionResponseData
Use PollOptionResponseData instead.
PollsFilter
= Filter <PollData >
Represents filtering options for polls.
PollVote
= PollVoteResponseData
Use PollVoteResponseData instead.
PollVotesFilter
= Filter <PollVoteData >
Represents filtering options for poll votes.
ProgressCallback
= void Function(int count , int total )
The type of a progress listening callback when sending or receiving data.
RejectAppealRequest
= RejectAppealRequestPayload
Use RejectAppealRequestPayload instead.
RequestEncoder
= FutureOr <List <int > > Function(String request , RequestOptions options )
The type of a request encoding callback.
ResponseDecoder
= FutureOr <String ? > Function(List <int > responseBytes , RequestOptions options , ResponseBody responseBody )
The type of a response decoding callback.
RestoreActionRequest
= RestoreActionRequestPayload
Use RestoreActionRequestPayload instead.
ShadowBlockActionRequest
= ShadowBlockActionRequestPayload
Use ShadowBlockActionRequestPayload instead.
SortFieldComparator <T >
= int Function(T? a , T? b , SortDirection direction , NullOrdering nullOrdering )
A comparator function that compares two instances of type T based on
a specified field, sort direction, and null ordering.
SortFieldValueGetter <T , V >
= V? Function(T )
Signature for a function that retrieves a sortable field value of type V from
an instance of type T.
StreamFeedsException
= StreamException
The root of the failures this SDK reports.
StreamLogCallback
= void Function(StreamLogRecord record )
Receives a log record on behalf of a StreamLogHandler.from handler.
StreamLogMessage
= String Function()
Builds a log message on demand.
UnbanActionRequest
= UnbanActionRequestPayload
Use UnbanActionRequestPayload instead.
UnblockActionRequest
= UnblockActionRequestPayload
Use UnblockActionRequestPayload instead.
UserMute
= UserMuteResponse
Use UserMuteResponse instead.
UsersFilter
= Filter <UserData >
Represents filtering options for users.
UserTokenLoader
= Future <UserToken > Function(String userId )
A function that loads user tokens.
ValidateStatus
= bool Function(int ? status )
The type of a response status code validate callback.
WebSocketAuthenticator
= Future <void > Function(WsRequestSender send , StreamApiException ? previousError )
A function that authenticates a newly opened connection.
WebSocketOptionsBuilder
= WebSocketOptions Function()
A function that builds the options for a connection attempt.
WebSocketProvider
= WebSocketChannel Function(WebSocketOptions options )
Signature for a function that creates a WebSocketChannel based on WebSocketOptions .
WsRequestSender
= Result <void > Function(WsRequest request )
A function that sends a request over a connection that is not usable yet.