AIAudioConfigResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

AIAudioConfigResponse({required bool enabled, required String profile, required List<BodyguardRule> rules})
const

Properties

copyWith → $AIAudioConfigResponseCopyWith<AIAudioConfigResponse>
Create a copy of AIAudioConfigResponse with the given fields replaced by the non-null parameter values.
no setterinherited
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
profile → String
final
rules → List<BodyguardRule>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → AIAudioConfigResponse