ActivityMarked class

An activity was marked as read, seen, or watched.

Inheritance

Constructors

ActivityMarked({required FidScope scope, required MarkActivityData data})
const

Properties

data → MarkActivityData
The marked activity data.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → FidScope
The feed scope this event applies to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited