ActivityRestoredEvent class

Inheritance
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

ActivityRestoredEvent({required ActivityResponse activity, required DateTime createdAt, required Map<String, Object?> custom, String? feedVisibility, required String fid, DateTime? receivedAt, required String type, UserResponseCommonFields? user})
const

Properties

activity ActivityResponse
final
copyWith → $ActivityRestoredEventCopyWith<ActivityRestoredEvent>
Create a copy of ActivityRestoredEvent with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
final
custom Map<String, Object?>
final
error Object?
no setterinherited
feedVisibility String?
final
fid String
final
hashCode int
The hash code for this object.
no setterinherited
healthCheckInfo HealthCheckInfo?
no setterinherited
receivedAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
user UserResponseCommonFields?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ActivityRestoredEvent