AddCommentsBatchRequest class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

AddCommentsBatchRequest({required List<AddCommentRequest> comments})
const

Properties

comments → List<AddCommentRequest>
final
copyWith → $AddCommentsBatchRequestCopyWith<AddCommentsBatchRequest>
Create a copy of AddCommentsBatchRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → AddCommentsBatchRequest