AppResponseFields class

Available extensions
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

AppResponseFields({required bool asyncUrlEnrichEnabled, required bool autoTranslationEnabled, required FileUploadConfig fileUploadConfig, required int id, required FileUploadConfig imageUploadConfig, required String name, required String placement})
const

Properties

asyncUrlEnrichEnabled → bool
final
autoTranslationEnabled → bool
final
copyWith → $AppResponseFieldsCopyWith<AppResponseFields>
Create a copy of AppResponseFields with the given fields replaced by the non-null parameter values.
no setterinherited
fileUploadConfig → FileUploadConfig
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
imageUploadConfig → FileUploadConfig
final
name → String
final
placement → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toModel() → AppData

Available on AppResponseFields, provided by the AppResponseFieldsMapper extension

Converts AppResponseFields to AppData.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → AppResponseFields