Attachment class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

Attachment({List<Action>? actions, String? assetUrl, String? authorIcon, String? authorLink, String? authorName, String? color, required Map<String, Object?> custom, String? fallback, List<Field>? fields, String? footer, String? footerIcon, Images? giphy, String? imageUrl, String? ogScrapeUrl, int? originalHeight, int? originalWidth, String? pretext, String? text, String? thumbUrl, String? title, String? titleLink, String? type})
const

Properties

actions → List<Action>?
final
assetUrl → String?
final
authorIcon → String?
final
final
authorName → String?
final
color → String?
final
copyWith → $AttachmentCopyWith<Attachment>
Create a copy of Attachment with the given fields replaced by the non-null parameter values.
no setterinherited
custom → Map<String, Object?>
final
fallback → String?
final
fields → List<Field>?
final
final
footerIcon → String?
final
giphy → Images?
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String?
final
ogScrapeUrl → String?
final
originalHeight → int?
final
originalWidth → int?
final
pretext → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
thumbUrl → String?
final
title → String?
final
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → Attachment