BookmarkList class

Represents a list of bookmarks with a query and state.

The primary interface for working with bookmark lists in the Stream Feeds SDK that provides functionality for querying and managing collections of bookmarks with pagination support.

Each bookmark list instance is associated with a specific query and maintains its own state that can be observed for real-time updates. The bookmark list state includes bookmarks and pagination information.

Mixed-in types

Properties

bookmarksRepository → BookmarksRepository
final
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Returns true if this object has been disposed.
no setterinherited
notifier → StateNotifier<BookmarkListState>
no setter
query → BookmarksQuery
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → BookmarkListState
no setter
stream → Stream<BookmarkListState>
no setter

Methods

dispose() → void
Disposes of this object.
override
get() → Future<Result<List<BookmarkData>>>
Queries the initial list of bookmarks based on the provided query.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryMoreBookmarks({int? limit}) → Future<Result<List<BookmarkData>>>
Loads more bookmarks based on the current pagination state.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited