BookmarksFilterField class

Represents a field that can be used in bookmarks filtering.

This extension type provides a type-safe way to specify which field should be used when creating filters for bookmarks queries.

Inheritance

Constructors

BookmarksFilterField(String remote, FilterFieldValueGetter<BookmarkData, Object> value)
Creates a new bookmarks filter field.

Properties

collectionEquality → CollectionEquality
The comparison Filter.equal makes against this field when both it and the value it is compared against hold several elements.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
remote → String
The remote field name used in API queries.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → FilterFieldValueGetter<BookmarkData, Object>
The function that extracts the field value of type T from a model instance.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

activityId → BookmarksFilterField
Filter by the unique identifier of the activity that was bookmarked.
final
createdAt → BookmarksFilterField
Filter by the creation timestamp of the bookmark.
final
folderId → BookmarksFilterField
Filter by the unique identifier of the bookmark folder.
final
updatedAt → BookmarksFilterField
Filter by the last update timestamp of the bookmark.
final
userId → BookmarksFilterField
Filter by the user ID who created the bookmark.
final