BulkActionAppealsRequest class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Properties

actionType → BulkActionAppealsRequestActionType
final
appealIds → List<String>
final
copyWith → $BulkActionAppealsRequestCopyWith<BulkActionAppealsRequest>
Create a copy of BulkActionAppealsRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
markReviewed → MarkReviewedRequestPayload?
final
rejectAppeal → RejectAppealRequestPayload?
final
restore → RestoreActionRequestPayload?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unban → UnbanActionRequestPayload?
final
unblock → UnblockActionRequestPayload?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → BulkActionAppealsRequest