CallActionOptions class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

CallActionOptions({int? duration, String? flagReason, String? kickReason, bool? muteAudio, bool? muteVideo, String? reason, String? warningText})
const

Properties

copyWith → $CallActionOptionsCopyWith<CallActionOptions>
Create a copy of CallActionOptions with the given fields replaced by the non-null parameter values.
no setterinherited
duration → int?
final
flagReason → String?
final
hashCode → int
The hash code for this object.
no setterinherited
kickReason → String?
final
muteAudio → bool?
final
muteVideo → bool?
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warningText → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → CallActionOptions