CallRuleActionSequence class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

CallRuleActionSequence({List<String>? actions, CallActionOptions? callOptions, int? violationNumber})
const

Properties

actions → List<String>?
final
callOptions → CallActionOptions?
final
copyWith → $CallRuleActionSequenceCopyWith<CallRuleActionSequence>
Create a copy of CallRuleActionSequence with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
violationNumber → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → CallRuleActionSequence