ChatModerationV2Response class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

ChatModerationV2Response({required String action, String? blocklistMatched, List<String>? blocklistsMatched, List<String>? imageHarms, required String originalText, bool? platformCircumvented, String? semanticFilterMatched, List<String>? textHarms})
const

Properties

action → String
final
blocklistMatched → String?
final
blocklistsMatched → List<String>?
final
copyWith → $ChatModerationV2ResponseCopyWith<ChatModerationV2Response>
Create a copy of ChatModerationV2Response with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
imageHarms → List<String>?
final
originalText → String
final
platformCircumvented → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticFilterMatched → String?
final
textHarms → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ChatModerationV2Response