Command class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

Command({required String args, DateTime? createdAt, required String description, required String name, required String set, DateTime? updatedAt})
const

Properties

args → String
final
copyWith → $CommandCopyWith<Command>
Create a copy of Command with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set → String
final
updatedAt → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → Command