CommentReplyListStateNotifier class

Manages the state of a comment reply list and handles state updates.

Provides methods to update the comment reply list state in response to data changes and real-time events from the Stream Feeds API.

Inheritance

Constructors

CommentReplyListStateNotifier({required String currentUserId, required String parentCommentId, required CommentReplyListState initialState})

Properties

commentSort → CommentsSort
no setter
currentUserId → String
final
debugState → CommentReplyListState
A development-only way to access state outside of StateNotifier.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
If a listener has been added using addListener and hasn't been removed yet.
no setterinherited
mounted → bool
Whether dispose was called or not.
no setterinherited
onError ↔ ErrorListener?
A callback for error reporting if one of the listeners added with addListener throws.
getter/setter pairinherited
parentCommentId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ CommentReplyListState
The current "state" of this StateNotifier.
getter/setter pairinherited
stream → Stream<CommentReplyListState>
A broadcast stream representation of a StateNotifier.
no setterinherited

Methods

addListener(Listener<CommentReplyListState> listener, {bool fireImmediately = true}) → RemoveListener
Subscribes to this object.
inherited
dispose() → void
Frees all the resources associated with this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onParentCommentDeleted() → void
Handles the deletion of the parent comment.
onQueryMoreReplies(PaginationResult<CommentData> result, CommentsSort? sort) → void
Handles the result of a query for replies to a comment.
onReplyAdded(CommentData reply) → void
Handles the addition of a new comment reply.
onReplyReactionRemoved(CommentData reply, FeedsReactionData reaction) → void
Handles the removal of a reaction from a comment reply.
onReplyReactionUpserted(CommentData reply, FeedsReactionData reaction, {bool enforceUnique = false}) → void
Handles the addition or update of a reaction to a comment reply.
onReplyRemoved(CommentData reply) → void
Handles the removal of a comment reply.
onReplyUpdated(CommentData reply) → void
Handles the update of an existing comment reply.
toString() → String
A string representation of this object.
inherited
updateShouldNotify(CommentReplyListState old, CommentReplyListState current) → bool
Whether to notify listeners or not when state changes
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited