operator property
The logical operator to use when combining policies (Operator.and or Operator.or).
Implementation
final Operator operator;
The logical operator to use when combining policies (Operator.and or Operator.or).
final Operator operator;