Connected class final

The WebSocket is fully connected and authenticated.

This state indicates that the connection is fully established and the client can send and receive messages. Health monitoring is active and the connection is considered stable.

Inheritance

Constructors

Connected({required HealthCheckInfo healthCheck})
Creates a Connected connection state.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthCheck → HealthCheckInfo
Health check information for the active WebSocket connection.
final
isActive → bool
Whether the connection state is currently active.
no setterinherited
isAutomaticReconnectionEnabled → bool
Whether automatic reconnection is enabled for this connection state.
no setterinherited
isConnected → bool
Whether the connection state is in connected state.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited