DraftPayloadResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

DraftPayloadResponse({List<Attachment>? attachments, required Map<String, Object?> custom, String? html, required String id, List<UserResponse>? mentionedUsers, String? mml, String? parentId, String? pollId, String? quotedMessageId, bool? showInChannel, bool? silent, required String text, String? type})
const

Properties

attachments → List<Attachment>?
final
copyWith → $DraftPayloadResponseCopyWith<DraftPayloadResponse>
Create a copy of DraftPayloadResponse with the given fields replaced by the non-null parameter values.
no setterinherited
custom → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
html → String?
final
id → String
final
mentionedUsers → List<UserResponse>?
final
mml → String?
final
parentId → String?
final
pollId → String?
final
quotedMessageId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInChannel → bool?
final
silent → bool?
final
text → String
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → DraftPayloadResponse