EnrichedCollectionResponse class

Available extensions
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

EnrichedCollectionResponse({DateTime? createdAt, Map<String, Object?>? custom, required String id, required String name, required EnrichedCollectionResponseStatus status, DateTime? updatedAt, String? userId})
const

Properties

copyWith → $EnrichedCollectionResponseCopyWith<EnrichedCollectionResponse>
Create a copy of EnrichedCollectionResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
final
custom → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → EnrichedCollectionResponseStatus
final
updatedAt → DateTime?
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toModel() → CollectionData

Available on EnrichedCollectionResponse, provided by the EnrichedCollectionResponseMapper extension

Converts this API enriched collection response to a domain CollectionData instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → EnrichedCollectionResponse