EscalatePayload class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
- EscalatePayload({String? notes, String? priority, String? reason})
-
const
Properties
-
copyWith
→ $EscalatePayloadCopyWith<
EscalatePayload> -
Create a copy of EscalatePayload
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes → String?
-
final
- priority → String?
-
final
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → EscalatePayload