FeedGroup class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

FeedGroup({ActivityFilterConfig? activityFilter, required List<ActivityProcessorConfig> activityProcessors, required List<ActivitySelectorConfig> activitySelectors, AggregationConfig? aggregation, required int aggregationVersion, required int appPk, required DateTime createdAt, required Map<String, Object?> custom, required String defaultFollowerRole, required String defaultVisibility, DateTime? deletedAt, required String groupId, DateTime? lastFeedGetAt, NotificationConfig? notification, PushNotificationConfig? pushNotification, RankingConfig? ranking, StoriesConfig? stories, required DateTime updatedAt})
const

Properties

activityFilter → ActivityFilterConfig?
final
activityProcessors → List<ActivityProcessorConfig>
final
activitySelectors → List<ActivitySelectorConfig>
final
aggregation → AggregationConfig?
final
aggregationVersion → int
final
appPk → int
final
copyWith → $FeedGroupCopyWith<FeedGroup>
Create a copy of FeedGroup with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
custom → Map<String, Object?>
final
defaultFollowerRole → String
final
defaultVisibility → String
final
deletedAt → DateTime?
final
groupId → String
final
hashCode → int
The hash code for this object.
no setterinherited
lastFeedGetAt → DateTime?
final
notification → NotificationConfig?
final
pushNotification → PushNotificationConfig?
final
ranking → RankingConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stories → StoriesConfig?
final
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FeedGroup