FeedsBookmarkResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

FeedsBookmarkResponse({String? activityId, required DateTime createdAt, Map<String, Object?>? custom, required String objectId, required String objectType, required DateTime updatedAt, required UserResponse user})
const

Properties

activityId → String?
final
copyWith → $FeedsBookmarkResponseCopyWith<FeedsBookmarkResponse>
Create a copy of FeedsBookmarkResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
custom → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
objectId → String
final
objectType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
user → UserResponse
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FeedsBookmarkResponse