FeedsFeedResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

FeedsFeedResponse({required int activityCount, required DateTime createdAt, required UserResponse createdBy, Map<String, Object?>? custom, DateTime? deletedAt, required String description, required String feed, List<String>? filterTags, required int followerCount, required int followingCount, required String groupId, required String id, FeedsActivityLocation? location, required int memberCount, required String name, required int pinCount, required DateTime updatedAt, String? visibility})
const

Properties

activityCount → int
final
copyWith → $FeedsFeedResponseCopyWith<FeedsFeedResponse>
Create a copy of FeedsFeedResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
createdBy → UserResponse
final
custom → Map<String, Object?>?
final
deletedAt → DateTime?
final
description → String
final
feed → String
final
filterTags → List<String>?
final
followerCount → int
final
followingCount → int
final
groupId → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
location → FeedsActivityLocation?
final
memberCount → int
final
name → String
final
pinCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
visibility → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FeedsFeedResponse