FileUploadConfig class

Available extensions
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

FileUploadConfig({required List<String> allowedFileExtensions, required List<String> allowedMimeTypes, required List<String> blockedFileExtensions, required List<String> blockedMimeTypes, required int sizeLimit})
const

Properties

allowedFileExtensions → List<String>
final
allowedMimeTypes → List<String>
final
blockedFileExtensions → List<String>
final
blockedMimeTypes → List<String>
final
copyWith → $FileUploadConfigCopyWith<FileUploadConfig>
Create a copy of FileUploadConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeLimit → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toModel() → FileUploadConfigData

Available on FileUploadConfig, provided by the FileUploadConfigMapper extension

Converts FileUploadConfig to FileUploadConfigData.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FileUploadConfig