FlagRequest class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

FlagRequest({Map<String, Object?>? custom, String? entityCreatorId, required String entityId, required String entityType, ModerationPayload? moderationPayload, String? reason})
const

Properties

copyWith → $FlagRequestCopyWith<FlagRequest>
Create a copy of FlagRequest with the given fields replaced by the non-null parameter values.
no setterinherited
custom → Map<String, Object?>?
final
entityCreatorId → String?
final
entityId → String
final
entityType → String
final
hashCode → int
The hash code for this object.
no setterinherited
moderationPayload → ModerationPayload?
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FlagRequest