MembersFilterField class

Represents a field that can be used in feed members filtering.

This extension type provides a type-safe way to specify which field should be used when creating filters for members queries.

Inheritance

Constructors

MembersFilterField(String remote, FilterFieldValueGetter<FeedMemberData, Object> value)
Creates a new members filter field.

Properties

collectionEquality → CollectionEquality
The comparison Filter.equal makes against this field when both it and the value it is compared against hold several elements.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
remote → String
The remote field name used in API queries.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → FilterFieldValueGetter<FeedMemberData, Object>
The function that extracts the field value of type T from a model instance.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

createdAt → MembersFilterField
Filter by the creation timestamp of the member.
final
role → MembersFilterField
Filter by the role of the member in the feed.
final
status → MembersFilterField
Filter by the status of the member (e.g., "accepted", "pending").
final
updatedAt → MembersFilterField
Filter by the last update timestamp of the member.
final
userId → MembersFilterField
Filter by the user ID of the member.
final