MembershipLevelResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

MembershipLevelResponse({required DateTime createdAt, Map<String, Object?>? custom, String? description, required String id, required String name, required int priority, required List<String> tags, required DateTime updatedAt})
const

Properties

copyWith → $MembershipLevelResponseCopyWith<MembershipLevelResponse>
Create a copy of MembershipLevelResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
custom → Map<String, Object?>?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MembershipLevelResponse