NotificationComment class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

NotificationComment({List<Attachment>? attachments, required String comment, required String id, required String userId})
const

Properties

attachments → List<Attachment>?
final
comment → String
final
copyWith → $NotificationCommentCopyWith<NotificationComment>
Create a copy of NotificationComment with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → NotificationComment