PollVoteListState class

An observable state object that manages the current state of a poll vote list.

Maintains the current list of poll votes and pagination information for efficient loading and navigation through poll vote collections.

Annotations
  • @freezed

Constructors

PollVoteListState({List<PollVoteData> votes = const [], PaginationData? pagination})
const

Properties

canLoadMore → bool
Indicates whether there are more votes available to load.
no setter
copyWith → $PollVoteListStateCopyWith<PollVoteListState>
Create a copy of PollVoteListState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pagination → PaginationData?
Last pagination information from the most recent request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
votes → List<PollVoteData>
All the paginated poll votes currently loaded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited