PollVoteResponseData class

Available extensions
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

PollVoteResponseData({String? answerText, Map<String, String>? answerTextI18n, required DateTime createdAt, required String id, bool? isAnswer, required String optionId, required String pollId, required DateTime updatedAt, UserResponse? user, String? userId})
const

Properties

answerText → String?
final
answerTextI18n → Map<String, String>?
final
copyWith → $PollVoteResponseDataCopyWith<PollVoteResponseData>
Create a copy of PollVoteResponseData with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isAnswer → bool?
final
optionId → String
final
pollId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
user → UserResponse?
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toModel() → PollVoteData

Available on PollVoteResponseData, provided by the PollVoteResponseMapper extension

Converts this API poll vote response to a domain PollVoteData instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → PollVoteResponseData