PollsFilterField class

Represents a field that can be used in polls filtering.

This extension type provides a type-safe way to specify which field should be used when creating filters for polls queries.

Inheritance

Constructors

PollsFilterField(String remote, FilterFieldValueGetter<PollData, Object> value)
Creates a new polls filter field.

Properties

collectionEquality → CollectionEquality
The comparison Filter.equal makes against this field when both it and the value it is compared against hold several elements.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
remote → String
The remote field name used in API queries.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → FilterFieldValueGetter<PollData, Object>
The function that extracts the field value of type T from a model instance.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

allowAnswers → PollsFilterField
Filter by whether the poll allows answers.
final
allowUserSuggestedOptions → PollsFilterField
Filter by whether the poll allows user-suggested options.
final
createdAt → PollsFilterField
Filter by the creation timestamp of the poll.
final
createdById → PollsFilterField
Filter by the ID of the user who created the poll.
final
id → PollsFilterField
Filter by the unique identifier of the poll.
final
isClosed → PollsFilterField
Filter by whether the poll is closed.
final
maxVotesAllowed → PollsFilterField
Filter by the maximum number of votes allowed per user.
final
name → PollsFilterField
Filter by the name of the poll.
final
updatedAt → PollsFilterField
Filter by the last update timestamp of the poll.
final
votingVisibility → PollsFilterField
Filter by the voting visibility setting of the poll.
final