QueryBookmarksResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

QueryBookmarksResponse({required List<BookmarkResponse> bookmarks, required String duration, String? next, String? prev})
const

Properties

bookmarks → List<BookmarkResponse>
final
copyWith → $QueryBookmarksResponseCopyWith<QueryBookmarksResponse>
Create a copy of QueryBookmarksResponse with the given fields replaced by the non-null parameter values.
no setterinherited
duration → String
final
hashCode → int
The hash code for this object.
no setterinherited
next → String?
final
prev → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → QueryBookmarksResponse