ReactionGroupUserResponse class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

ReactionGroupUserResponse({required DateTime createdAt, UserResponse? user, required String userId})
const

Properties

copyWith → $ReactionGroupUserResponseCopyWith<ReactionGroupUserResponse>
Create a copy of ReactionGroupUserResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → UserResponse?
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ReactionGroupUserResponse