feedList abstract method

FeedList feedList(
  1. FeedsQuery query
)

Creates a feed list instance based on the provided query.

Creates a FeedList object that represents a collection of feeds matching the specified query. The feed list can be used to fetch multiple feeds, manage feed groups, and receive real-time updates for all feeds in the list.

Example:

final feedList = client.feedList(FeedsQuery(
  filter: Filter.equal(FeedsFilterField.visibility, 'public'),
  sort: [FeedsSort.desc(FeedsSortField.followerCount)],
  limit: 25,
));

final result = await feedList.get();

Returns a FeedList instance that can be used to interact with the collection of feeds.

Implementation

FeedList feedList(FeedsQuery query);