UpdateCommentRequest class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

UpdateCommentRequest({List<Attachment>? attachments, String? comment, bool? copyCustomToNotification, Map<String, Object?>? custom, bool? handleMentionNotifications, List<String>? mentionedUserIds, bool? skipEnrichUrl, bool? skipPush})
const

Properties

attachments → List<Attachment>?
final
comment → String?
final
copyCustomToNotification → bool?
final
copyWith → $UpdateCommentRequestCopyWith<UpdateCommentRequest>
Create a copy of UpdateCommentRequest with the given fields replaced by the non-null parameter values.
no setterinherited
custom → Map<String, Object?>?
final
handleMentionNotifications → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
mentionedUserIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipEnrichUrl → bool?
final
skipPush → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UpdateCommentRequest