UploadInProgress class final

The upload is on its way, progress bytes of the file sent so far.

Inheritance

Constructors

UploadInProgress({required UploadProgress progress})
Creates an UploadInProgress state.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isFinal bool
Whether the upload has settled, with no further state to follow.
no setterinherited
progress UploadProgress
How far the upload has got.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited