UpsertActionConfigItem class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

UpsertActionConfigItem({required String action, Map<String, Object?>? custom, String? description, required String entityType, String? icon, String? id, required int order, String? queueType})
const

Properties

action String
final
copyWith → $UpsertActionConfigItemCopyWith<UpsertActionConfigItem>
Create a copy of UpsertActionConfigItem with the given fields replaced by the non-null parameter values.
no setterinherited
custom Map<String, Object?>?
final
description String?
final
entityType String
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
id String?
final
order int
final
queueType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) UpsertActionConfigItem