UserCustomPropertyParameters class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

UserCustomPropertyParameters({String? operator, String? propertyKey})
const

Properties

copyWith → $UserCustomPropertyParametersCopyWith<UserCustomPropertyParameters>
Create a copy of UserCustomPropertyParameters with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
operator → String?
final
propertyKey → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UserCustomPropertyParameters