UserInterestRequest class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

UserInterestRequest({required String tag, double? weight})
const

Properties

copyWith → $UserInterestRequestCopyWith<UserInterestRequest>
Create a copy of UserInterestRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final
weight → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UserInterestRequest