WebSocketAutomaticReconnectionPolicy class

A reconnection policy that checks if automatic reconnection is enabled based on the current state of the WebSocket connection.

Implemented types

Properties

connectionState → ConnectionStateEmitter
The WebSocket client to check for reconnection settings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canBeReconnected() → bool
Determines whether the WebSocket should attempt to reconnect automatically.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited