BatchFollowData class
Represents the result of a batch follow operation.
Contains information about follows that were created and all follows (including existing and newly created ones).
- Annotations
-
- @freezed
Constructors
-
BatchFollowData({required List<
FollowData> created, required List<FollowData> follows}) -
const
Properties
-
copyWith
→ $BatchFollowDataCopyWith<
BatchFollowData> -
Create a copy of BatchFollowData
with the given fields replaced by the non-null parameter values.
no setterinherited
-
created
→ List<
FollowData> -
The follows that were created as a result of the batch operation.
final
-
follows
→ List<
FollowData> -
All follows, including existing and newly created ones.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited