ChannelConfigWithInfo class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
ChannelConfigWithInfo({List<
String> ? allowedFlagReasons, required ChannelConfigWithInfoAutomod automod, required ChannelConfigWithInfoAutomodBehavior automodBehavior, Thresholds? automodThresholds, String? blocklist, ChannelConfigWithInfoBlocklistBehavior? blocklistBehavior, List<BlockListOptions> ? blocklists, ChatPreferences? chatPreferences, required List<Command> commands, required bool connectEvents, required bool countMessages, required DateTime createdAt, required bool customEvents, required bool deliveryEvents, Map<String, List< ? grants, required bool markMessagesPending, required int maxMessageLength, required String messageRetention, required bool mutes, required String name, int? partitionSize, String? partitionTtl, required bool polls, ChannelConfigWithInfoPushLevel? pushLevel, required bool pushNotifications, required bool quotes, required bool reactions, required bool readEvents, required bool reminders, required bool replies, required bool search, required bool skipLastMsgUpdateForSystemMsgs, required bool typingEvents, required DateTime updatedAt, required bool uploads, required bool urlEnrichment, required bool userMessageReminders})String> > -
const
Properties
-
allowedFlagReasons
→ List<
String> ? -
final
- automod → ChannelConfigWithInfoAutomod
-
final
- automodBehavior → ChannelConfigWithInfoAutomodBehavior
-
final
- automodThresholds → Thresholds?
-
final
- blocklist → String?
-
final
- blocklistBehavior → ChannelConfigWithInfoBlocklistBehavior?
-
final
-
blocklists
→ List<
BlockListOptions> ? -
final
- chatPreferences → ChatPreferences?
-
final
-
commands
→ List<
Command> -
final
- connectEvents → bool
-
final
-
copyWith
→ $ChannelConfigWithInfoCopyWith<
ChannelConfigWithInfo> -
Create a copy of ChannelConfigWithInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- countMessages → bool
-
final
- createdAt → DateTime
-
final
- customEvents → bool
-
final
- deliveryEvents → bool
-
final
-
grants
→ Map<
String, List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- markMessagesPending → bool
-
final
- maxMessageLength → int
-
final
- messageRetention → String
-
final
- mutes → bool
-
final
- name → String
-
final
- partitionSize → int?
-
final
- partitionTtl → String?
-
final
- polls → bool
-
final
- pushLevel → ChannelConfigWithInfoPushLevel?
-
final
- pushNotifications → bool
-
final
- quotes → bool
-
final
- reactions → bool
-
final
- readEvents → bool
-
final
- reminders → bool
-
final
- replies → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → bool
-
final
-
final
- skipLastMsgUpdateForSystemMsgs → bool
-
final
- typingEvents → bool
-
final
- updatedAt → DateTime
-
final
- uploads → bool
-
final
- urlEnrichment → bool
-
final
- userMessageReminders → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ChannelConfigWithInfo