ChatPreferences class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
Properties
- channelMentions → String?
-
final
-
copyWith
→ $ChatPreferencesCopyWith<
ChatPreferences> -
Create a copy of ChatPreferences
with the given fields replaced by the non-null parameter values.
no setterinherited
- defaultPreference → String?
-
final
- directMentions → String?
-
final
- distinctChannelMessages → String?
-
final
- groupMentions → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hereMentions → String?
-
final
- roleMentions → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threadReplies → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ChatPreferences