ConfigResponse class
- Available extensions
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
ConfigResponse({AIAudioConfigResponse? aiAudioConfig, AIImageConfig? aiImageConfig, List<
AIImageLabelDefinition> ? aiImageLabelDefinitions, Map<String, List< ? aiImageSubclassifications, AITextConfig? aiTextConfig, AIVideoConfigResponse? aiVideoConfig, required bool async, AutomodPlatformCircumventionConfig? automodPlatformCircumventionConfig, AutomodSemanticFiltersConfig? automodSemanticFiltersConfig, AutomodToxicityConfig? automodToxicityConfig, List<String> >BodyguardProfileSummary> ? availableBodyguardProfiles, BlockListConfig? blockListConfig, required DateTime createdAt, FloodConfig? floodConfig, required String key, LLMConfig? llmConfig, required List<String> supportedVideoCallHarmTypes, required String team, required DateTime updatedAt, VelocityFilterConfig? velocityFilterConfig, VideoCallRuleConfig? videoCallRuleConfig}) -
const
Properties
- aiAudioConfig → AIAudioConfigResponse?
-
final
- aiImageConfig → AIImageConfig?
-
final
-
aiImageLabelDefinitions
→ List<
AIImageLabelDefinition> ? -
final
-
aiImageSubclassifications
→ Map<
String, List< ?String> > -
final
- aiTextConfig → AITextConfig?
-
final
- aiVideoConfig → AIVideoConfigResponse?
-
final
- async → bool
-
final
- automodPlatformCircumventionConfig → AutomodPlatformCircumventionConfig?
-
final
- automodSemanticFiltersConfig → AutomodSemanticFiltersConfig?
-
final
- automodToxicityConfig → AutomodToxicityConfig?
-
final
-
availableBodyguardProfiles
→ List<
BodyguardProfileSummary> ? -
final
- blockListConfig → BlockListConfig?
-
final
-
copyWith
→ $ConfigResponseCopyWith<
ConfigResponse> -
Create a copy of ConfigResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
final
- floodConfig → FloodConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- llmConfig → LLMConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedVideoCallHarmTypes
→ List<
String> -
final
- team → String
-
final
- updatedAt → DateTime
-
final
- velocityFilterConfig → VelocityFilterConfig?
-
final
- videoCallRuleConfig → VideoCallRuleConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toModel(
) → ModerationConfigData -
Available on ConfigResponse, provided by the ModerationConfigDataMapper extension
Converts this API moderation configuration to a domain ModerationConfigData instance. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ConfigResponse