FeedOwnData class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
FeedOwnData({List<
FeedOwnCapability> ? ownCapabilities, List<FollowResponse> ? ownFollowings, List<FollowResponse> ? ownFollows, FeedMemberResponse? ownMembership}) -
const
Properties
-
copyWith
→ $FeedOwnDataCopyWith<
FeedOwnData> -
Create a copy of FeedOwnData
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ownCapabilities
→ List<
FeedOwnCapability> ? -
final
-
ownFollowings
→ List<
FollowResponse> ? -
final
-
ownFollows
→ List<
FollowResponse> ? -
final
- ownMembership → FeedMemberResponse?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → FeedOwnData