FeedRequest class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
FeedRequest({String? createdById, Map<
String, Object?> ? custom, String? description, required String feedGroupId, required String feedId, List<String> ? filterTags, Location? location, List<FeedMemberRequest> ? members, String? name, FeedRequestVisibility? visibility}) -
const
Properties
-
copyWith
→ $FeedRequestCopyWith<
FeedRequest> -
Create a copy of FeedRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdById → String?
-
final
-
custom
→ Map<
String, Object?> ? -
final
- description → String?
-
final
- feedGroupId → String
-
final
- feedId → String
-
final
-
filterTags
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → Location?
-
final
-
members
→ List<
FeedMemberRequest> ? -
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visibility → FeedRequestVisibility?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → FeedRequest