ModerationQueueResponse class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
ModerationQueueResponse({required DateTime createdAt, required String createdBy, required String description, required Map<
String, Object?> filters, required String id, required int itemCount, required String name, required List<Map< sort, required String type, required DateTime updatedAt})String, Object?> > -
const
Properties
-
copyWith
→ $ModerationQueueResponseCopyWith<
ModerationQueueResponse> -
Create a copy of ModerationQueueResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
final
- createdBy → String
-
final
- description → String
-
final
-
filters
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- itemCount → int
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sort
→ List<
Map< String, Object?> > -
final
- type → String
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ModerationQueueResponse