PlatformType enum
Enumeration of supported platform types.
Defines all platforms that can be detected by the Stream Core SDK, including mobile, desktop, web, and specialized platforms. Each platform type includes its corresponding operating system identifier string.
Values
- android → const PlatformType
-
Android: www.android.com/
const PlatformType('android') - ios → const PlatformType
-
iOS: www.apple.com/ios/
const PlatformType('ios') - web → const PlatformType
-
web: en.wikipedia.org/wiki/World_Wide_Web
const PlatformType('web') - macOS → const PlatformType
-
macOS: www.apple.com/macos
const PlatformType('macos') - windows → const PlatformType
-
Windows: www.windows.com
const PlatformType('windows') - linux → const PlatformType
-
Linux: www.linux.org
const PlatformType('linux') - fuchsia → const PlatformType
-
Fuchsia: fuchsia.dev/fuchsia-src/concepts
const PlatformType('fuchsia')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - operatingSystem → String
-
The operating system identifier string for this platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PlatformType> - A constant List of the values in this enum, in order of their declaration.