ReviewQueueItemResponse class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
ReviewQueueItemResponse({required List<
ActionLogResponse> actions, EnrichedActivity? activity, required String aiTextSeverity, AppealItemResponse? appeal, UserResponse? assignedTo, required List<BanInfoResponse> bans, ModerationCallResponse? call, DateTime? completedAt, double? confidenceScore, String? configKey, required DateTime createdAt, EntityCreatorResponse? entityCreator, String? entityCreatorId, required String entityId, required String entityType, required bool escalated, DateTime? escalatedAt, String? escalatedBy, EscalationMetadata? escalationMetadata, EnrichedActivity? feedsV2Activity, Reaction? feedsV2Reaction, FeedsV3ActivityResponse? feedsV3Activity, FeedsV3CommentResponse? feedsV3Comment, required List<ModerationFlagResponse> flags, required int flagsCount, required String id, required List<String> languages, required String latestModeratorAction, ChatMessageResponse? message, ModerationPayloadResponse? moderationPayload, Reaction? reaction, required String recommendedAction, DateTime? reviewedAt, required String reviewedBy, required int severity, required String status, List<String> ? teams, required DateTime updatedAt}) -
const
Properties
-
actions
→ List<
ActionLogResponse> -
final
- activity → EnrichedActivity?
-
final
- aiTextSeverity → String
-
final
- appeal → AppealItemResponse?
-
final
- assignedTo → UserResponse?
-
final
-
bans
→ List<
BanInfoResponse> -
final
- call → ModerationCallResponse?
-
final
- completedAt → DateTime?
-
final
- confidenceScore → double?
-
final
- configKey → String?
-
final
-
copyWith
→ $ReviewQueueItemResponseCopyWith<
ReviewQueueItemResponse> -
Create a copy of ReviewQueueItemResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
final
- entityCreator → EntityCreatorResponse?
-
final
- entityCreatorId → String?
-
final
- entityId → String
-
final
- entityType → String
-
final
- escalated → bool
-
final
- escalatedAt → DateTime?
-
final
- escalatedBy → String?
-
final
- escalationMetadata → EscalationMetadata?
-
final
- feedsV2Activity → EnrichedActivity?
-
final
- feedsV2Reaction → Reaction?
-
final
- feedsV3Activity → FeedsV3ActivityResponse?
-
final
- feedsV3Comment → FeedsV3CommentResponse?
-
final
-
flags
→ List<
ModerationFlagResponse> -
final
- flagsCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
languages
→ List<
String> -
final
- latestModeratorAction → String
-
final
- message → ChatMessageResponse?
-
final
- moderationPayload → ModerationPayloadResponse?
-
final
- reaction → Reaction?
-
final
- recommendedAction → String
-
final
- reviewedAt → DateTime?
-
final
- reviewedBy → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → int
-
final
- status → String
-
final
-
teams
→ List<
String> ? -
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ReviewQueueItemResponse