ShareResponse class
- Available extensions
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
const
Properties
- activityId → String
-
final
-
copyWith
→ $ShareResponseCopyWith<
ShareResponse> -
Create a copy of ShareResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserResponse
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toModel(
) → ShareData -
Available on ShareResponse, provided by the ShareResponseMapper extension
Converts this API share response to a domain ShareData instance. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ShareResponse