SharedLocationResponse class
- Annotations
-
- @freezed
- @immutable
- @JsonSerializable.new()
Constructors
-
const
Properties
- channel → ChannelResponse?
-
final
- channelCid → String
-
final
-
copyWith
→ $SharedLocationResponseCopyWith<
SharedLocationResponse> -
Create a copy of SharedLocationResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
final
- createdByDeviceId → String
-
final
- duration → String
-
final
- endAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
final
- longitude → double
-
final
- message → MessageResponse?
-
final
- messageId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → SharedLocationResponse