StreamErrorCodePredicates extension
Convenience predicates grouping the codes that share a remedy.
Properties
- isApiKeyInvalid → bool
-
Available on StreamErrorCode, provided by the StreamErrorCodePredicates extension
Whether this code says the API key cannot be accepted (StreamErrorCode.apiKeyInvalid).no setter - isTokenExpired → bool
-
Available on StreamErrorCode, provided by the StreamErrorCodePredicates extension
Whether this code says the token has expired (StreamErrorCode.tokenExpired).no setter - isTokenNotYetValid → bool
-
Available on StreamErrorCode, provided by the StreamErrorCodePredicates extension
Whether this code says the token is not valid yet (StreamErrorCode.tokenNotValidYet and StreamErrorCode.tokenUsedBeforeIssuedAt).no setter - isTokenSignatureInvalid → bool
-
Available on StreamErrorCode, provided by the StreamErrorCodePredicates extension
Whether this code says the token's signature cannot be accepted (StreamErrorCode.tokenSignatureInvalid).no setter